| Title: | Lorem-Ipsum-like Helpers for fast Shiny Prototyping |
|---|---|
| Description: | Prototype your shiny apps quickly with these Lorem-Ipsum-like Helpers. |
| Authors: | Colin Fay [cre, aut] (ORCID: <https://orcid.org/0000-0001-7343-1846>), Sebastien Rochette [aut] (ORCID: <https://orcid.org/0000-0002-1565-9313>), ThinkR [cph, fnd] |
| Maintainer: | Colin Fay <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-12 11:24:39 UTC |
| Source: | https://github.com/ThinkR-open/shinipsum |
Get a shinipsum example
ipsum_examples(which = NULL)ipsum_examples(which = NULL)
which |
The example to run. If empty, all the available examples are listed. |
A path to the example.
ipsum_examples()ipsum_examples()
A long lorem ipsum text
loremlorem
An object of class character of length 1.
A long vector of words
lorem_wordslorem_words
An object of class character of length 13657.
This function creates a random DT::datatable, and can be passed into renderDT & DTOutput.
random_DT( nrow, ncol, type = c("random", "numeric", "character", "numchar"), ... )random_DT( nrow, ncol, type = c("random", "numeric", "character", "numchar"), ... )
nrow |
number of row of the output |
ncol |
number of cols of the output |
type |
type of the columns, can be "random", "numeric", "character", "numchar". Default is random. |
... |
arguments to be passed to DT::datatable |
a DT
This function returns a dygraph object, which can be passed to renderDygraph and dygraphOutput
random_dygraph(...)random_dygraph(...)
... |
args passed to |
a dygraph
This function returns a ggplot object, which can be passed to renderPlot and plotOutput
random_ggplot( type = c("random", "point", "bar", "boxplot", "col", "tile", "line", "bin2d", "contour", "density", "density_2d", "dotplot", "hex", "freqpoly", "histogram", "ribbon", "raster", "tile", "violin") )random_ggplot( type = c("random", "point", "bar", "boxplot", "col", "tile", "line", "bin2d", "contour", "density", "density_2d", "dotplot", "hex", "freqpoly", "histogram", "ribbon", "raster", "tile", "violin") )
type |
type of the geom. Can be any of "random", "point", "bar", "boxplot","col", "tile", "line", "bin2d", "contour", "density", "density_2d", "dotplot", "hex", "freqpoly", "histogram", "ribbon", "raster", "tile", "violin" and defines the geom of the ggplot. Default is "random", and chooses a random geom for you. |
a ggplot
This function returns a ggplotly object, which can be passed to renderPlotly and plotlyOutput
random_ggplotly(...)random_ggplotly(...)
... |
arg to pass to |
a ggplotly
This function returns a random image that can be passed into renderImage and plotOutput.
random_image()random_image()
an image
This function returns a model which can be passed to renderText or renderTable if pre-processed appropriately
random_lm(nobs = 100, nx = 2)random_lm(nobs = 100, nx = 2)
nobs |
Numeric. number of observation |
nx |
Numeric. number of variables. Should be lower that nobs |
a model output
This function returns a random print output that can be passed to renderPrint and verbatimTextOutput.
random_print(type = c("character", "numeric", "integer", "model", "table"))random_print(type = c("character", "numeric", "integer", "model", "table"))
type |
type of the output ("character", "numeric", "model", "table") |
a random print
This function returns a table that can be passed to renderTable and tableOutput.
random_table(nrow, ncol, type = c("random", "numeric", "character", "numchar"))random_table(nrow, ncol, type = c("random", "numeric", "character", "numchar"))
nrow |
number of row of the output |
ncol |
number of cols of the output |
type |
type of the columns, can be "random", "numeric", "character", "numchar". Default is random. |
a table
A Random Lorem Ipsum
random_text(nchars = NULL, nwords = NULL, offset = 0)random_text(nchars = NULL, nwords = NULL, offset = 0)
nchars |
number of characters. One of the two params should be left NULL. |
nwords |
number of words to return. One of the two params should be left NULL. |
offset |
number of characters or words to offset the result by. Defaults to 0. |
a text